from changeless.types import create_fancy_model, create_immutable_model

def fancy_list(db_function):
    def create_fancy():
        return lambda: [ create_fancy_model(db_entry) for db_entry in db_function() ]
    return create_fancy()

def immutable_list(db_function):
    def create_immutable():
        return lambda: [ create_immutable_model(db_entry) for db_entry in db_function() ]
    return create_immutable()

def fancy_gen(db_function):
    def create_fancy():
        return lambda: _fancy_gen( db_function() )

    return create_fancy()

def immutable_gen(db_function):
    def create_immutable():
        return lambda: _immutable_gen( db_function() )

    return create_immutable()

def _immutable_gen(query_set):
    for db_entry in query_set:
        yield create_immutable_model(db_entry)

def _fancy_gen(query_set):
    for db_entry in query_set:
        yield create_fancy_model(db_entry)




import unittest
from changeless.types.conversion_helpers import model_to_dict
from django.test.simple import DjangoTestSuiteRunner
from test_helpers import load_fixtures
from changeless.test.myapp.models import Library, Book, Address
import pprint

class TestConverters(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        test_runner = DjangoTestSuiteRunner(interactive=False, verbosity=1)
        test_db = test_runner.setup_databases()
        load_fixtures()

    #def test_model_to_dict(self):
    #    pp = pprint.PrettyPrinter(indent=4)
    #    model_dict = model_to_dict(Book.objects.get(title="A Tale of Two Cities"))

    #    pp.pprint(model_dict)

    #    self.assertTrue(False)

